@@ -18,7 +18,7 @@
          release the mutex.  Have the one "parent" listen for UDP
          packets again while the "child" processes the packet */
 
-int decompress_data(js_string *compressed, js_string *uncompressed) {
+int legacy_decompress_data(js_string *compressed, js_string *uncompressed) {
     uint16 type,newrdlength,rdlength;
     int counter,place,uplace,ccount,rdptr,temp;
     q_header hdr;
