@@ -15,7 +15,7 @@ extern int js_space_chars();
 
 /* Keywords that are non-dictionary strings in Mara's rc file */
 
-#define KEYCOUNT 30
+#define KEYCOUNT 31
 
 char *keywords[KEYCOUNT] = {
         "bind_address", /* Address to bind to (0.0.0.0 is all addresses) */
@@ -80,6 +80,8 @@ char *keywords[KEYCOUNT] = {
 	                 to the server */
 	"verbose_query", /* Whether to output every query the recursive DNS
 			    server makes */
+	"no_cname_warnings", /* Whether to supress warnings about dangling
+				CNAME records. */
         "zone_transfer_acl" /* ACL of IPs allowed to perform zone transfers */
         };
 
