@@ -24,10 +24,13 @@
 #include "functions_server.h"
 
 extern int log_level;
+extern int no_cname_warnings;
 
 extern int mhash_firstkey();
 extern int mhash_nextkey();
 
+extern void human_readable_dns_query();
+
 /* Handler to handle warnings.
    Input: Pointer to js_string object with warning message,
           line number (-1 to display no line number)
@@ -133,8 +136,8 @@ int change_rtype(js_string *js, int newtype) {
 int mhash_put_rr(mhash *hash, js_string *query, js_string *value, uint32 ttl,
                  uint32 authoritative, uint32 expire) {
 
-    rr *data;
-    js_string *new;
+    rr *data = 0;
+    js_string *new = 0;
     int ret, rrtype;
     /* Create a structure for putting the rr data in */
     if((data = js_alloc(1,sizeof(rr))) == 0)
@@ -147,6 +150,7 @@ int mhash_put_rr(mhash *hash, js_string *query, js_string *value, uint32 ttl,
     data->seen = 0;
     data->zap = 0;
     data->ptr = 0;
+    data->rcode = 0;
 
     /* Store the simple data in the rr data */
     data->expire = 0;
@@ -212,8 +216,8 @@ int mhash_put_rr(mhash *hash, js_string *query, js_string *value, uint32 ttl,
 int mhash_add_rr(mhash *hash, js_string *query, js_string *value, uint32 ttl,
                  uint32 authoritative, uint32 expire) {
 
-    rr *data, *point;
-    js_string *new;
+    rr *data = 0, *point = 0;
+    js_string *new = 0;
     mhash_e spot_data;
     int rrtype;
 
@@ -228,6 +232,7 @@ int mhash_add_rr(mhash *hash, js_string *query, js_string *value, uint32 ttl,
     data->seen = 0;
     data->zap = 0;
     data->ptr = 0;
+    data->rcode = 0;
 
     /* Store the simple data in the rr data */
     data->expire = 0;
@@ -370,8 +375,8 @@ int mhash_add_ptr(mhash *hash, js_string *query, js_string *value) {
 
 int mhash_add_ip(mhash *hash, js_string *query, js_string *value) {
 
-    rr *data, *point;
-    js_string *new, *new_query;
+    rr *data = 0, *point = 0;
+    js_string *new = 0, *new_query = 0;
     mhash_e spot_data;
     int rrtype;
 
@@ -386,6 +391,7 @@ int mhash_add_ip(mhash *hash, js_string *query, js_string *value) {
     data->seen = 0;
     data->zap = 0;
     data->ptr = 0;
+    data->rcode = 0;
 
     /* Since we are adding an IP, the rrtype is always RR_A */
     rrtype = RR_A;
@@ -921,10 +927,10 @@ int add_an(mhash *bighash, js_string *error) {
         qtype = get_rtype(query);
         if(qtype == JS_ERROR)
             continue;
+        qdata = mhash_get(bighash,query);
         /* If it is a MX/NS/CNAME query, proceed to find the assosciated
            A value (if it exists) */
         if(qtype == RR_MX || qtype == RR_NS || qtype == RR_CNAME) {
-            qdata = mhash_get(bighash,query);
             if(qdata.datatype == MARA_DNSRR) {
                 /* See if we have a corresponding A record for each of
                    the answers */
@@ -950,6 +956,12 @@ int add_an(mhash *bighash, js_string *error) {
                                 }
                             }
                         }
+		    else if(qtype == RR_CNAME && no_cname_warnings == 0) {
+			printf("Warning: The CNAME record ");
+			human_readable_dns_query(query,1);
+			printf("does not have an A record.\n"
+"Please read the FAQ entry about FAQ entry about dangling CNAME records.\n");
+		        }
                     } while ((record = record->next) != 0);
                 }
             }
